package com.zehong.entity;

import com.fasterxml.jackson.annotation.JsonFormat;
import lombok.Data;

import java.math.BigDecimal;
import java.util.Date;

/**
 * 阀控数据对象 t_controller_values_data
 * 
 * @author zehong
 * @date 2022-05-07
 */
@Data
public class TControllerValuesData {

    /** 阀控id */
    private Long controllerValueId;

    /** 厂商编号 */
    private String manufacturersId;

    /** 阀控类型 */
    private String equipmentTypeValue;

    /** 阀控编号 */
    private String valueId;

    /** 阀控协议类型：保留，目前未使用，全FF表示数据无效 */
    private String protocolType;

    /** 阀门操作类型，十六进制，0：温控，1：常开，2：常关，3：自由温控；4：强制；5：用户控制；6：固定温控 */
    private String valveOperateType;

    /** 温度下限 */
    private BigDecimal lowControlTemperatureRange;

    /** 温度上限 */
    private BigDecimal highControlTemperatureRange;

    /** 室内温控器向阀门上报室温最大时间周期，单位分钟，范围1到30，全FF表示数据无效 */
    private String indoorTemperatureReportMaxTimer;

    /** 温控温度 */
    private BigDecimal controlTemperature;

    /** 室内温度 */
    private BigDecimal indoorTemperature;

    /** 当前阀门开关状态 0：关闭；100：打开；对于开度阀0、10、…100对应0~10挡位 */
    private String openedPercent;

    /** 阀门关机防冻标记，0：关闭关机防冻功能；1：打开关机防冻功能 */
    private String preventFrozenFlag;

    /** 阀门控制器与室内温控器通信方式，0：无线；1：有线 */
    private String communicateType;

    /** 阀门控制器供电方式，0：市电；1：电池 */
    private String valvePowerStyle;

    /** 允许的最大挡位，十六进制数，0、10、… 100对应0~10挡位 */
    private String panelPowerTyle;

    /** 对码状态，十六进制数，0：未对码；1：已对码 */
    private String pairingStatus;

    /** 阀门累计开时间，单位秒 */
    private String cumulativeOpenedTime;

    /** 阀门累计工作时间，单位秒 */
    private String cumulativeWorkingTime;

    /** 实时时间 */
    @JsonFormat(pattern = "yyyy-MM-dd")
    private Date dateTimeValue;

    /** 十六进制，高字节为阀门控制器状态，低字节为室内温控器状态 */
    private String status;

    /** 累计阀开/关次数 */
    private String cumulativeOpenAndCloseTimes;

    /** 累计室温*时间（分钟） */
    private String cumulativeIndoorTempMultiplySecond;

    /** 软件版本，十六进制数，高位为主版本号；低位为次版本号 */
    private String softwareVersion;

    /** 频点，十六进制数，全FF表示数据无效 */
    private String freq;

    /** Snum，十六进制数，全FF表示数据无效 */
    private String snum;

    /** 创建时间 */
    private Date createTime;
}
