package com.zehong.netty.decode;

import java.util.zip.CRC32;

/**
 * @author gengd
 * 16进制消息串解析
 */
public class MsgDecode {

    /**
     * 16进制消息串
     */
    private String msgStr;
    /** 消息头
     * Fixed Preamble 前导码：0x49 0x4f 0x54 0x40 4个字节
     * Length 长度：指示后续数据的长度，高位在前、低位在后 2个字节
     * Transmission ID 传输ID 1个字节
     * Concentrator ID 集中器ID，高位在前、低位在后 4个字节
     * Message Type 消息类型 1个字节
     */
    private String msgHead;
    /** 信息单元 */
    private String msgInfo;
    /** 消息尾
     * CRC32 Check 校验码 4个字节
     *  Terminator 结束符 2个字节
     */
    private String msgTail;

    public MsgDecode(String msgStr){
        this.msgStr = msgStr;
        this.msgHead = msgStr.substring(0,24);
        this.msgInfo = msgStr.substring(24,msgStr.length()-12);
        this.msgTail = msgStr.substring(msgStr.length()-12,msgStr.length());
    }

    /**
     * 获取传输id
     * @return String
     */
    public String getTransmissionId(){
        return this.msgHead.substring(12,14);
    }

    /**
     * 获取集中器id
     * @return
     */
    public String getConcentratorId(){
        return this.msgHead.substring(14,22);
    }

    /**
     * 获取消息类型
     * @return
     */
    public String getMessageType(){
        return this.msgHead.substring(22,24);
    }

    /**
     * crc32校验
     * @return boolean
     */
    public boolean checkCRC32Code(){
        String checkStr = this.msgStr.substring(8,this.msgStr.length()-12);
        CRC32 crc32 = new CRC32();
        crc32.update(checkStr.getBytes());
        String checkCode = Long.toHexString(crc32.getValue());
        String crc32Code = this.msgTail.substring(0,8);
        return checkCode.equals(crc32Code);
    }

    public String getMsgStr() {
        return msgStr;
    }

    public String getMsgHead() {
        return msgHead;
    }

    public String getMsgInfo() {
        return msgInfo;
    }

    public String getMsgTail() {
        return msgTail;
    }
}
