package com.zehong.netty.decode;

import com.zehong.entity.TControllerValuesData;
import com.zehong.service.ITControllerValuesDataService;
import com.zehong.utils.DateTimeValueUtil;
import com.zehong.utils.HexUtils;
import com.zehong.utils.SpringUtil;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.util.StringUtils;

import java.math.BigDecimal;
import java.text.ParseException;
import java.text.SimpleDateFormat;

/**
 * @gengd
 * 阀控数据解析
 */
public class ValveDataListsDecode {

    private Logger logger = LoggerFactory.getLogger(ValveDataListsDecode.class);

    private MsgDecode decode;

    /**
     * 阀控list数据
     */
    private String valueDataLists;

    /**
     * 阀控数据长度
     */
    public int valueDataListsLength;

    public ValveDataListsDecode(MsgDecode decode,int startLength){
        this.decode = decode;
        this.valueDataLists = decode.getMsgInfo().substring(42 + startLength *2,decode.getMsgInfo().length());
    }

    /**
     * 解析阀控数据
     */
   public void decodeValueDataLists(){
       //信息单元类型
       String ieType = this.valueDataLists.substring(0,2);
       //长度
       String length = this.valueDataLists.substring(2,6);
       //阀控数量
       String valueDataCount = this.valueDataLists.substring(6,10);
       //热量表数据所占字节数
       this.valueDataListsLength = Integer.parseInt(valueDataCount,16) * 54 + 5;
       //热量表数据
       decodeValueData(Integer.parseInt(valueDataCount,16));
       logger.info("transmissionId:" + decode.getTransmissionId() + "阀控数据： 信息单元类型："+ ieType +" 长度：" + length + "阀控数量：" + valueDataListsLength + "阀控数据：" + valueDataLists.substring(10,Integer.parseInt(valueDataCount,16)*108));
   }

    /**
     * 解析阀控数据
     * @param count 数量
     */
  private void decodeValueData(int count){
      String heatMeterDatas = valueDataLists.substring(10,valueDataLists.length());
      for(int i = 1; i < count + 1; i++){
          String valueData = heatMeterDatas.substring((i-1)*108,i*108);
          saveValusData(valueData);
      }
   }

    /**
     * 保存阀控数据
     * @param valueData 阀控数据
     */
   private void saveValusData(String valueData){
       ITControllerValuesDataService itControllerValuesDataService = SpringUtil.getBean(ITControllerValuesDataService.class);
       TControllerValuesData tControllerValuesData = decodeValueData(valueData);
       itControllerValuesDataService.insertTControllerValuesData(tControllerValuesData);
   }

    /**
     * 解析阀控表数据
     * @param valueData  阀控数据
     * @return TControllerValuesData
     */
   private TControllerValuesData decodeValueData(String valueData){
       TControllerValuesData tControllerValuesData = new TControllerValuesData();
       //厂商编号
       String manufacturersId = valueData.substring(0,4);
       tControllerValuesData.setManufacturersId(manufacturersId);
       //阀控类型
       String equipmentTypeValue = valueData.substring(4,6);
       tControllerValuesData.setEquipmentTypeValue(equipmentTypeValue);
       //阀控编号
       String valveId = valueData.substring(6,16);
       tControllerValuesData.setValueId(valveId);
       //阀门操作类型
       String valveOperateType = valueData.substring(18,20);
       tControllerValuesData.setValveOperateType(String.valueOf(Integer.parseInt(valveOperateType,16)));
       /**
        * 十六进制数，高位在前、低位在后，两位小数，单位℃
        * 小于20000表示温控温度范围下限，例如01 02表示0x0102除100，即2.58℃。
        * 大于20000表示回水温度，例如4F 22，0x4F22=20258，（20258-20000）/100=2.58℃
        * 全FF表示数据无效
        */
       String lowControlTemperatureRange = valueData.substring(20,24);
       int lowControlTemperatureRangeInt = Integer.parseInt(lowControlTemperatureRange,16);
       if(lowControlTemperatureRangeInt > 2000){
           tControllerValuesData.setLowControlTemperatureRange(new BigDecimal((lowControlTemperatureRangeInt-2000)/100));
       }else{
           tControllerValuesData.setLowControlTemperatureRange(new BigDecimal(lowControlTemperatureRangeInt/100));
       }
       //温控温度范围上限
       String highControlTemperatureRange = valueData.substring(24,28);
       tControllerValuesData.setHighControlTemperatureRange(new BigDecimal(Integer.parseInt(highControlTemperatureRange,16)/100));
       //室内温控器向阀门上报室温最大时间周期，单位分钟，范围1到30
       String indoortemperaturereportMaxTimer = valueData.substring(28,30);
       tControllerValuesData.setIndoorTemperatureReportMaxTimer(String.valueOf(Integer.parseInt(indoortemperaturereportMaxTimer,16)));
       //温控温度
       String controlTemperature = valueData.substring(30,34);
       tControllerValuesData.setControlTemperature(new BigDecimal(Integer.parseInt(controlTemperature,16)/100));
       //室内温度
       String indoorTemperature = valueData.substring(34,38);
       tControllerValuesData.setIndoorTemperature(new BigDecimal(Integer.parseInt(indoorTemperature,16)/100));
       //当前阀门开关状态
       String openedPercent = valueData.substring(38,40);
       tControllerValuesData.setOpenedPercent(String.valueOf(Integer.parseInt(openedPercent,16)));
       //阀门关机防冻标记
       String preventFrozenFlag = valueData.substring(40,42);
       tControllerValuesData.setPreventFrozenFlag(String.valueOf(Integer.parseInt(preventFrozenFlag,16)));
       //阀门控制器与室内温控器通信方式
       String communicateType = valueData.substring(42,44);
       tControllerValuesData.setCommunicateType(String.valueOf(Integer.parseInt(communicateType,16)));
       //阀门控制器供电方式
       String valvePowerStyle = valueData.substring(44,46);
       tControllerValuesData.setValvePowerStyle(String.valueOf(Integer.parseInt(valvePowerStyle,16)));
       //允许的最大挡位
       String panelPowerStyle = valueData.substring(46,48);
       tControllerValuesData.setPanelPowerTyle(String.valueOf(Integer.parseInt(panelPowerStyle,16)));
       //对码状态
       String pairingStatus = valueData.substring(48,50);
       tControllerValuesData.setPairingStatus(String.valueOf(Integer.parseInt(pairingStatus,16)));
       //阀门累计开时间 单位秒
       String cumulativeOpenedTime = valueData.substring(50,58);
       tControllerValuesData.setCumulativeOpenedTime(String.valueOf(Integer.parseInt(cumulativeOpenedTime,16)));
       //阀门累计工作时间 单位秒
       String cumulativeWorkingTime = valueData.substring(58,66);
       tControllerValuesData.setCumulativeWorkingTime(String.valueOf(Integer.parseInt(cumulativeWorkingTime,16)));
       //实时时间
       String dateTimeValue = valueData.substring(66,80);
       try {
           tControllerValuesData.setDateTimeValue(new SimpleDateFormat("yyyy-MM-dd HH:mm:ss").parse( DateTimeValueUtil.getDateTimeStr(dateTimeValue)));
       } catch (ParseException e) {
           logger.error("阀控数据时间解析失败！");
       }
       //状态
       String status = valueData.substring(80,84);
       tControllerValuesData.setStatus("高位："+HexUtils.hexToBinary(status.substring(0,2))+" 低位：" +HexUtils.hexToBinary(status.substring(2,4)));
       //累计阀开/关次数
       String cumulativeOpenSndCloseTimes = valueData.substring(84,92);
       tControllerValuesData.setCumulativeOpenAndCloseTimes(String.valueOf(Integer.parseInt(cumulativeOpenSndCloseTimes,16)));
       //累计室温*时间（分钟）
       String cumulativeIndoorTempMultiplySecond = valueData.substring(92,100);
       tControllerValuesData.setCumulativeIndoorTempMultiplySecond(String.valueOf(Integer.parseInt(cumulativeIndoorTempMultiplySecond,16)));
       //软件版本
       String softwareVersion = valueData.substring(100,104);
       tControllerValuesData.setSoftwareVersion(softwareVersion);
       //频点
       String freq = valueData.substring(104,106);
       tControllerValuesData.setFreq(freq);
       String snum = valueData.substring(106,108);
       tControllerValuesData.setSnum(snum);
       return tControllerValuesData;

   }


}
