package com.zehong.service.impl;

import cn.hutool.core.date.DateUtil;
import com.github.pagehelper.PageInfo;
import com.zehong.dao.TControllerValuesDataDao;
import com.zehong.entity.TControllerValuesData;
import com.zehong.service.ITControllerValuesDataService;
import org.springframework.stereotype.Service;
import javax.annotation.Resource;
import java.util.List;

/**
 * 阀控数据Service业务层处理
 * 
 * @author zehong
 * @date 2022-05-07
 */
@Service
public class TControllerValuesDataServiceImpl implements ITControllerValuesDataService {

    @Resource
    private TControllerValuesDataDao tControllerValuesDataDao;

    /**
     * 查询阀控数据
     * 
     * @param controllerValueId 阀控数据ID
     * @return 阀控数据
     */
    @Override
    public TControllerValuesData selectTControllerValuesDataById(Long controllerValueId){
        return tControllerValuesDataDao.selectTControllerValuesDataById(controllerValueId);
    }

    /**
     * 查询阀控数据列表
     * 
     * @param tControllerValuesData 阀控数据
     * @return 阀控数据
     */
    @Override
    public List<TControllerValuesData> selectTControllerValuesDataList(TControllerValuesData tControllerValuesData) {
        return tControllerValuesDataDao.selectTControllerValuesDataList(tControllerValuesData);
    }

    /**
     * 查询阀控数据分页列表
     *
     * @param tControllerValuesData 阀控数据
     * @return 阀控数据
     */
    @Override
    public PageInfo<TControllerValuesData> selectTControllerValuesDataPage(TControllerValuesData tControllerValuesData) {
        return new PageInfo(tControllerValuesDataDao.selectTControllerValuesDataList(tControllerValuesData));
    }

    /**
     * 新增阀控数据
     * 
     * @param tControllerValuesData 阀控数据
     * @return 结果
     */
    @Override
    public int insertTControllerValuesData(TControllerValuesData tControllerValuesData){
        tControllerValuesData.setCreateTime(DateUtil.date());
        return tControllerValuesDataDao.insertTControllerValuesData(tControllerValuesData);
    }

    /**
     * 修改阀控数据
     * 
     * @param tControllerValuesData 阀控数据
     * @return 结果
     */
    @Override
    public int updateTControllerValuesData(TControllerValuesData tControllerValuesData){
        return tControllerValuesDataDao.updateTControllerValuesData(tControllerValuesData);
    }

    /**
     * 批量删除阀控数据
     * 
     * @param controllerValueIds 需要删除的阀控数据ID
     * @return 结果
     */
    @Override
    public int deleteTControllerValuesDataByIds(Long[] controllerValueIds){
        return tControllerValuesDataDao.deleteTControllerValuesDataByIds(controllerValueIds);
    }

    /**
     * 删除阀控数据信息
     * 
     * @param controllerValueId 阀控数据ID
     * @return 结果
     */
    @Override
    public int deleteTControllerValuesDataById(Long controllerValueId){
        return tControllerValuesDataDao.deleteTControllerValuesDataById(controllerValueId);
    }
}
