package com.zehong.service.impl;

import cn.hutool.core.date.DateUtil;
import com.github.pagehelper.PageInfo;
import com.zehong.dao.THeatDataDao;
import com.zehong.entity.THeatData;
import com.zehong.service.ITHeatDataService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.List;

/**
 * 热量数据Service业务层处理
 * 
 * @author zehong
 * @date 2022-05-07
 */
@Service
public class THeatDataServiceImpl implements ITHeatDataService {

    @Resource
    private THeatDataDao tHeatDataDao;

    /**
     * 查询热量数据
     * 
     * @param heatId 热量数据ID
     * @return 热量数据
     */
    @Override
    public THeatData selectTHeatDataById(Long heatId){
        return tHeatDataDao.selectTHeatDataById(heatId);
    }

    /**
     * 查询热量数据列表
     * 
     * @param tHeatData 热量数据
     * @return 热量数据
     */
    @Override
    public List<THeatData> selectTHeatDataList(THeatData tHeatData){
        return tHeatDataDao.selectTHeatDataList(tHeatData);
    }

    /**
     * 查询热量数据分页列表
     *
     * @param tHeatData 热量数据
     * @return 热量数据
     */
    @Override
    public PageInfo<THeatData> selectTHeatDataPage(THeatData tHeatData) {
        return new PageInfo(tHeatDataDao.selectTHeatDataList(tHeatData));
    }

    /**
     * 新增热量数据
     * 
     * @param tHeatData 热量数据
     * @return 结果
     */
    @Override
    public int insertTHeatData(THeatData tHeatData){
        tHeatData.setCreateTime(DateUtil.date());
        return tHeatDataDao.insertTHeatData(tHeatData);
    }

    /**
     * 修改热量数据
     * 
     * @param tHeatData 热量数据
     * @return 结果
     */
    @Override
    public int updateTHeatData(THeatData tHeatData){
        return tHeatDataDao.updateTHeatData(tHeatData);
    }

    /**
     * 批量删除热量数据
     * 
     * @param heatIds 需要删除的热量数据ID
     * @return 结果
     */
    @Override
    public int deleteTHeatDataByIds(Long[] heatIds){
        return tHeatDataDao.deleteTHeatDataByIds(heatIds);
    }

    /**
     * 删除热量数据信息
     * 
     * @param heatId 热量数据ID
     * @return 结果
     */
    @Override
    public int deleteTHeatDataById(Long heatId){
        return tHeatDataDao.deleteTHeatDataById(heatId);
    }
}
